import {FC, useEffect, useState} from "react";
import {Checkbox, CheckboxGroup, Radio, RadioGroup, Text, View} from "@tarojs/components";
import './topic.scss'
import MyButton from "@/components/button/MyButton";

interface Props {
  data: Multi
  onAnswer: (isAnswer: boolean) => void
  onUpAndDown?: (index: number) => void
  index: number
  validate: boolean
  frequency?: number
  end?: boolean
}

const Multi: FC<Props> = ({data, onAnswer, onUpAndDown, index, validate, frequency, end}) => {
  const [rightAnswer, setRightAnswer] = useState<string[]>([]) //答案

  const rightKey = data?.right_answer?.split(',') || []  // 正确答案数组
  const [error, setError] = useState(false)

  const answers = [
    {value: "A", title: data.answerA},
    {value: "B", title: data.answerB},
    {value: "C", title: data.answerC},
    {value: "D", title: data.answerD},
  ]

  function onChange(e) {
    const value = e.detail.value
    if (data.type) {
      setRightAnswer(value)
    } else {
      setRightAnswer([value])
    }
  }

  useEffect(() => {
    if (validate) {
      const isAnswer = rightKey.toString() === rightAnswer.toString()
      onAnswer(isAnswer)
      setError(!isAnswer)
    }
  }, [validate])

  return (
    <View className='topic'>
      <View className='mb-3'>
        <Text className={'topicType'}>{data.type ? "多选题" : '单选题'}</Text>
        <Text>{data.question}</Text>
      </View>

      <View>
        {data.type ? <CheckboxGroup onChange={onChange}>
            {answers.map(d => <Checkbox
              key={d.value}
              value={d.value}
              className='option'
              disabled={validate}
            >
              <Text className='title'>{d.value}：{d.title}</Text>
            </Checkbox>)}
          </CheckboxGroup>
          : <RadioGroup onChange={onChange}>
            {answers.map(d => <Radio
              key={d.value}
              value={d.value}
              className='option'
              color={validate ? rightKey.includes(d.value) ? '#45d4a8' : 'red' : '#45d4a8'}
              disabled={validate ? !rightAnswer.includes(d.value) : false}
            >
              <Text className='title'>{d.value}：{d.title}</Text>
            </Radio>)}
          </RadioGroup>
        }
      </View>

      {onUpAndDown && <View className='upAndDown'>
        {index > 0 && <MyButton size='mini' width={150} onClick={() => onUpAndDown?.(index - 1)}>上一题</MyButton>}
        {!end && <MyButton size='mini' width={150} onClick={() => onUpAndDown?.(index + 1)}>下一题</MyButton>}
      </View>}


      {error && frequency == 0 && <View className='mt-3'>
        <View className='right_answer'>正确答案：{data.right_answer}</View>
        <View className='font-weight my-3'>题目解析</View>
        <View>{data.analysis}</View>
      </View>}
    </View>
  )
}

export default Multi
