import {FC, useRef, useState} from "react";
import {Button, Form, Image, Input, View} from "@tarojs/components";
import {Profile} from "@/store";
import {userApi} from "@/api";
import Taro from "@tarojs/taro";
import {regexTel} from "@/utils/regu";
import styles from './check.module.scss'

const uuid = () => {
  return 'xxxxxxxx-xxxx-4xxx-yxxx-xxxxxxxxxxxx'.replace(/[xy]/g, function (c) {
    const r = Math.random() * 16 | 0
    const v = c === 'x' ? r : (r & 0x3 | 0x8)
    return v.toString(16)
  }).replace(/-/g, '')
}

const Bing: FC = () => {
  const form = useRef<HTMLFormElement | null>(null)
  const [loading, setLoading] = useState(false)
  const {setUser, setToken, setCompany} = Profile.useContainer()
  const [captchaKey, setCaptchaKey] = useState(uuid())
  const openid = localStorage.getItem('openid')

  async function Submit(data) {
    setLoading(true)
    const value = data.target.value
    if (!regexTel.exec(value.phone_number)) {
      Taro.showToast({title: '手机号错误', icon: 'error'})
      setLoading(false)
      return
    }
    try {
      const res = await userApi.checkout({
        ...value,
        catch_key: captchaKey,
        openid,
      })
      if (res) {
        setCompany(res.company)
        setUser(res.user)
        setToken(res.token)
        Taro.switchTab({url: '/pages/index/index'})
      }
    } catch (e) {
      setCaptchaKey(uuid)
    }
    setLoading(false)
  }

  return (
    <View className='h-10 pt-6 px-3 bg-white'>
      <Form className='form' onSubmit={Submit} ref={form}>
        <View className='item'>
          <View>手机号</View>
          <Input name='phone_number' placeholder={'请输入手机号'}/>
        </View>

        <View className='item'>
          <View>验证码</View>

          <View className='flex align-center flex-1'>
            <Input name='code' className='flex-1' placeholder={'请输入验证码'}/>
            <Image className='w-2 ml-1' style='height:28px'
                   src={process.env.TARO_APP_API + '/api/v1/captcha?key=' + captchaKey}
                   onClick={() => setCaptchaKey(uuid)}/>
          </View>
        </View>

        <Button
          className={'button ' + styles.submit}
          style={{margin: '30px auto'}}
          formType='submit'
          disabled={loading}
        >
          提交
        </Button>
      </Form>
    </View>
  )
}

const Index: FC = () => {
  return (
    <Profile.Provider>
      <Bing/>
    </Profile.Provider>
  );
}

export default Index;
