import {Button, Form, Input, View} from "@tarojs/components";
import {FC, useEffect, useState} from "react";
import {ManageApi, Student} from "@/api/manage";
import Icon from "@/components/icon";
import Taro from "@tarojs/taro";
import {curriculum} from "@/api";
import './addStudent.scss'
import {getCurrentInstance} from "@tarojs/runtime";
import {Profile} from '@/store'
import CustomPageContainer from "@/components/custom-page-container/custom-page-container";

interface Department {
  id: number
  title: string
}

const AddStudent = () => {
  const [userInfo, setUerInfo] = useState<Student | null>(null)
  const [department, setDepartment] = useState<Department[]>([])
  const [show, setShow] = useState(false)
  const [depIds, setDepIds] = useState<number[]>([])
  const params = getCurrentInstance()?.router?.params as { id?: number }
  const [disable, setDisable] = useState(false)
  const {company} = Profile.useContainer()


  async function getDepartment() {
    const res = await curriculum.department()
    if (res) {
      setDepartment(res.data.map(d => ({title: d.name, id: d.id})))
    }
  }

  async function submit(event) {
    const value: Student = event.detail.value
    for (const [key, value1] of Object.entries(value)) {
      if (!value1 && !['id_card', 'password'].includes(key)) {
        Taro.showToast({title: "请填写完整", icon: 'error'})
        return
      }
    }
    Taro.showLoading()
    setDisable(true)
    try {
      if (params.id) {
        await ManageApi.putUser(params.id, {...value, dep_ids: depIds, company_id: company?.id || 0})
      } else {
        await ManageApi.addUser({...value, dep_ids: depIds, company_id: company?.id || 0})
      }
      Taro.hideLoading()
      Taro.showToast({title: "添加成功", icon: 'success'})
      setTimeout(() => {
        Taro.navigateBack()
      }, 500)
    } catch (e) {
      console.log(e)
    }
    Taro.hideLoading()
    setDisable(true)
  }

  function changeDepIds(item: Department) {
    const ids: number[] = JSON.parse(JSON.stringify(depIds))
    const index = depIds.indexOf(item.id)
    if (index === -1) {
      ids.push(item.id)
    } else {
      ids.splice(index, 1)
    }

    if (ids.length < 1) {
      Taro.showToast({title: '最少一个部门'})
      return
    }
    setDepIds(ids)
  }

  function formatDep() {
    const selected = department.filter(d => depIds.includes(d.id)).map(d => d.title)
    const top4 = selected.splice(0, 3).join('、')
    return top4 + (selected.length ? "+" + selected.length : '')
  }

  async function getUserInfo() {
    const res = await ManageApi.userInfo(params.id!)
    setUerInfo(res.user)
    setDepIds(res.dep_ids)
  }

  useEffect(() => {
    getDepartment()
    if (params.id) {
      getUserInfo()
    }
  }, [params.id])

  return (
    <View className='bg-white px-2'>
      <Form className='form' onSubmit={submit}>
        <View className='item'>
          <View>姓名</View>
          <Input placeholder='请输入学员姓名' name='name' value={userInfo?.name}
                 onInput={(event) => setUerInfo({...userInfo, name: event.detail.value} as Student)}/>
        </View>


        <View className='item'>
          <View>手机号</View>
          <Input
            placeholder='请输入手机号'
            name='phone_number'
            value={userInfo?.phone_number}
            onInput={(event) => setUerInfo({...userInfo, phone_number: event.detail.value} as Student)}/>
        </View>


        <View className='item'>
          <View>所属部门</View>
          <View className='flex align-center' onClick={() => setShow(true)}>
            <View>
              {depIds.length ? formatDep() : '请选择'}
            </View>
            <Icon name='chevron-right'/>
          </View>
        </View>

        <Button className='add button' formType='submit' disabled={disable}>新建</Button>
      </Form>

      <CustomPageContainer show={show} round>
        <View className='px-2 pt-1' style='text-align:right' onClick={() => setShow(false)}>确定</View>
        <View className='h-4 p-2 flex flex-wrap align-start'>
          {department?.map(item => {
            return (
              <View className={'mx-2 dep ' + (depIds.includes(item.id) ? ' depSelected' : '')}
                    onClick={() => changeDepIds(item)}>
                {item.title}
              </View>
            )
          })}
        </View>
      </CustomPageContainer>
    </View>
  )
}

const AddPage: FC = () => {
  return (
      <Profile.Provider>
        <AddStudent/>
      </Profile.Provider>
  )
}

export default AddPage
